/* faToNib - Convert from .fa to .nib format. */
#include "common.h"
#include "cheapcgi.h"
#include "linefile.h"
#include "nib.h"
#include "dnaseq.h"
#include "fa.h"

boolean maskLower = FALSE;

void usage()
/* Explain usage and exit. */
{
errAbort(
  "faToNib - Convert from .fa to .nib format.  Only uses first \n"
  "sequence in .fa\n"
  "usage:\n"
  "   faToNib in.fa out.nib\n"
  "options:\n"
  "   -maskLower - treat lower case sequence as N's\n");
}

void lcMask(char *s, int size)
/* Turn lower case to n's and upper case to lower case. */
{
char c;
while (--size >= 0)
   {
   c = *s;
   if (isupper(c))
      {
      *s++ = tolower(c);
      }
   else
      {
      *s++ = 'n';
      }
   }
}

void faToNib(char *in, char *out)
/* faToNib - Convert from .fa to .nib format. */
{
struct dnaSeq seq;
struct lineFile *lf = lineFileOpen(in, TRUE);
int faCount = 0;
boolean ok;

dnaUtilOpen();
for (;;)
    {
    if (maskLower)
       {
       ok =  faMixedSpeedReadNext(lf, &seq.dna, &seq.size, &seq.name);
       if (ok)
	   {
	   lcMask(seq.dna, seq.size);
	   }
       }
    else
       {
       ok =  faSpeedReadNext(lf, &seq.dna, &seq.size, &seq.name);
       }
    if (!ok)
       break;
    ++faCount;
    if (faCount > 1)
	{
        warn("More than one sequence in %s", in);
	break;
	}
    nibWrite(&seq, out);
    }
lineFileClose(&lf);
}

int main(int argc, char *argv[])
/* Process command line. */
{
cgiSpoof(&argc, argv);
if (argc != 3)
    usage();
maskLower = cgiBoolean("maskLower");
faToNib(argv[1], argv[2]);
return 0;
}
